@@ -178,12 +178,6 @@ getFunctions <- function(f) {
     "sum" = function(x) {
       base::sum(x, na.rm = TRUE)
     },
-    "iqr" = function(x) {
-      stats::IQR(x, na.rm = TRUE)
-    },
-    "range" = function(x) {
-      base::diff(base::range(x, na.rm = TRUE))
-    },
     "sd" = function(x) {
       stats::sd(x, na.rm = TRUE)
     },
@@ -240,6 +234,9 @@ getFunctions <- function(f) {
     },
     "q95" = function(x) {
       stats::quantile(x, 0.95, na.rm = TRUE)
+    },
+    "missing" = function(x) {
+      base::sum(base::as.numeric(base::is.na(x)), na.rm = TRUE)
     }
   )
   return(estimatesFunc[f])
